@@ -287,6 +287,7 @@ def snowflake_stage_load_copy_remove(
     type: str = "json",
     on_error: str = "skip_file",
     file_format_options: str = "",
+    remove_logs: bool = False,
 ) -> None:
     """
     Upload file to stage, copy to table, remove file from stage on Snowflake
@@ -313,7 +314,11 @@ def snowflake_stage_load_copy_remove(
 
         remove_query = f"remove @{stage} pattern='{file_pattern}'"
 
-    logging.basicConfig(stream=sys.stdout, level=20)
+    if remove_logs:
+        # Only read critical logs.
+        logging.basicConfig(stream=sys.stdout, level=logging.CRITICAL)
+    else:
+        logging.basicConfig(stream=sys.stdout, level=20)
 
     try:
         connection = engine.connect()
